@@ -19,21 +19,19 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const Format = imports.format;
+import GLib from 'gi://GLib';
+import Soup from 'gi://Soup';
 
-const GLib = imports.gi.GLib;
-const Soup = imports.gi.Soup;
-
-const Application = imports.application;
-const HTTP = imports.http;
-const PhotonParser = imports.photonParser;
-const Service = imports.service;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import * as HTTP from './http.js';
+import * as PhotonUtils from './photonUtils.js';
+import * as Service from './service.js';
+import * as Utils from './utils.js';
 
 // HTTP session timeout (in seconds)
 const TIMEOUT = 5;
 
-var GraphHopperGeocode = class {
+export class GraphHopperGeocode {
     constructor() {
         this._session =
             new Soup.Session({ user_agent : 'gnome-maps/' + pkg.version,
@@ -46,21 +44,20 @@ var GraphHopperGeocode = class {
         let url = this._buildURL(string, latitude, longitude);
         let msg = Soup.Message.new('GET', url);
 
-        let handler = cancellable.connect(() => {
-            this._session.cancel_message(msg, Soup.Status.CANCELLED);
-        });
-
-        this._session.queue_message(msg, (session, message) => {
-            cancellable.disconnect(handler);
-
+        this._session.send_and_read_async(msg, GLib.PRIORITY_DEFAULT,
+                                          cancellable,
+                                          (source, res) => {
             if (cancellable.is_cancelled())
                 return;
 
-            if (message.status_code !== Soup.KnownStatusCode.OK) {
-                callback(null, msg.status_code);
+            if (msg.get_status() !== Soup.Status.OK) {
+                callback(null, msg.get_status());
             } else {
                 try {
-                    let result = this._parseMessage(message.response_body.data);
+                    let buffer =
+                        this._session.send_and_read_finish(res).get_data();
+                    let result = this._parseMessage(Utils.getBufferText(buffer));
+
                     if (!result)
                         callback(null, null);
                     else
@@ -78,10 +75,13 @@ var GraphHopperGeocode = class {
         let msg = Soup.Message.new('GET', url);
 
         Application.application.mark_busy();
-        this._session.queue_message(msg, (session, message) => {
+        this._session.send_and_read_async(msg, GLib.PRIORITY_DEFAULT, null,
+                                          (source, res) => {
             Application.application.unmark_busy();
             try {
-                let result = this._parseMessage(message.response_body.data);
+                let buffer = this._session.send_and_read_finish(res).get_data();
+
+                let result = this._parseMessage(Utils.getBufferText(buffer));
                 if (!result)
                     callback(null, null);
                 else
@@ -133,7 +133,7 @@ var GraphHopperGeocode = class {
         let lat = hit.point.lat;
         let lon = hit.point.lng;
 
-        return PhotonParser.parsePlace(lat, lon, hit);
+        return PhotonUtils.parsePlace(lat, lon, hit);
     }
 
     _buildURL(string, latitude, longitude) {
@@ -141,16 +141,18 @@ var GraphHopperGeocode = class {
                                      locale:  this._language,
                                      key:     this._apiKey
                                    });
-        if (latitude !== null && longitude != null)
+        if (latitude !== null && longitude != null) {
             query.add('point', latitude + ',' + longitude);
+            if (string)
+                query.add('location_bias_scale', PhotonUtils.LOCATION_BIAS_SCALE);
+        }
 
         if (string)
             query.add('q', string);
         else
             query.add('reverse', 'true');
 
-        return Format.vprintf('%s/api/1/geocode?%s', [this._baseUrl,
-                                                      query.toString()]);
+        return `${this._baseUrl}/api/1/geocode?${query.toString()}`;
     }
 
     _readService() {
