@@ -83,9 +83,16 @@ export class MapWalker extends GObject.Object {
     zoomToFit() {
         let zoom = this._getZoomLevel();
 
-        this._mapView.map.go_to_full(this.place.location.latitude,
-                                     this.place.location.longitude,
-                                     zoom);
+         /*
+         * WORKAROUND!!!!
+         *
+         * For now disable the animation to prevent getting
+         * throttled by the tile server:
+         * https://gitlab.gnome.org/GNOME/gnome-maps/-/issues/546
+         */
+        this._mapView.map.center_on(this.place.location.latitude,
+                                    this.place.location.longitude);
+        this._mapView.map.viewport.zoom_level = zoom;
     }
 
     goTo(animate, linear) {
