@@ -17,15 +17,15 @@
  * Author: Rishi Raj Singh Jhelumi <rishiraj.devel@gmail.com>
  */
 
-const Format = imports.format;
-const Geocode = imports.gi.GeocodeGlib;
-const GObject = imports.gi.GObject;
-const Soup = imports.gi.Soup;
+import Geocode from 'gi://GeocodeGlib';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Soup from 'gi://Soup';
 
-const OSMNames = imports.osmNames;
-const PhotonParser = imports.photonParser;
-const Place = imports.place;
-const Utils = imports.utils;
+import * as OSMNames from './osmNames.js';
+import * as PhotonUtils from './photonUtils.js';
+import {Place} from './place.js';
+import * as Utils from './utils.js';
 
 const _DEFAULT_TIMEOUT = 180;
 const _DEFAULT_MAXSIZE = 536870912;
@@ -36,21 +36,12 @@ const _DEFAULT_OUTPUT_SORT_ORDER = 'qt';
 
 const BASE_URL = 'https://overpass-api.de/api/interpreter';
 
-var Overpass = GObject.registerClass({
-    Properties: {
-        'place': GObject.ParamSpec.object('place',
-                                          'Place',
-                                          'Place with added information',
-                                          GObject.ParamFlags.READABLE |
-                                          GObject.ParamFlags.WRITABLE,
-                                          Geocode.Place)
-    }
-}, class Overpass extends GObject.Object {
+export class Overpass extends GObject.Object {
 
-    _init(params) {
+    constructor(params) {
         params = params || { };
 
-        super._init();
+        super();
 
         // maximum allowed runtime for the query in seconds
         this.timeout = params.timeout || _DEFAULT_TIMEOUT;
@@ -77,17 +68,18 @@ var Overpass = GObject.registerClass({
     addInfo(place) {
         let url = this._getQueryUrl(Utils.osmTypeToString(place.osm_type),
                                     place.osm_id);
-        let uri = new Soup.URI(url);
-        let request = new Soup.Message({ method: 'GET',
-                                         uri: uri });
+        let request = Soup.Message.new('GET', url);
 
-        this._session.queue_message(request, (obj, message) => {
-            if (message.status_code !== Soup.KnownStatusCode.OK) {
-                Utils.debug('Failed to fetch Overpass result: ' + message.status_code);
+        this._session.send_and_read_async(request, GLib.PRIORITY_DEFAULT, null,
+                                          (source, res) => {
+            if (request.get_status() !== Soup.Status.OK) {
+                Utils.debug('Failed to fetch Overpass result: ' +
+                            request.get_status());
                 return;
             }
             try {
-                let jsonObj = JSON.parse(message.response_body.data);
+                let buffer = this._session.send_and_read_finish(res).get_data();
+                let jsonObj = JSON.parse(Utils.getBufferText(buffer));
                 this._populatePlace(place, jsonObj);
                 this.place = place;
                 this.notify('place');
@@ -98,18 +90,20 @@ var Overpass = GObject.registerClass({
     }
 
     fetchPlace(osmType, osmId, callback) {
-        let url = this._getQueryUrl(osmType, osmId);
-        let uri = new Soup.URI(url);
-        let request = new Soup.Message({ method: 'GET',
-                                         uri: uri });
+        let url = this._getQueryUrl(osmType, osmId)
+        let request = Soup.Message.new('GET', url);
 
-        this._session.queue_message(request, (obj, message) => {
-            if (message.status_code !== Soup.KnownStatusCode.OK) {
-                Utils.debug('Failed to fetch Overpass result: ' + message.status_code);
+        this._session.send_and_read_async(request, GLib.PRIORITY_DEFAULT, null,
+                                          (source, res) => {
+            if (request.get_status() !== Soup.Status.OK) {
+                Utils.debug('Failed to fetch Overpass result: ' +
+                            request.get_status());
                 callback(null);
+                return;
             }
             try {
-                let jsonObj = JSON.parse(message.response_body.data);
+                let buffer = this._session.send_and_read_finish(res).get_data();
+                let jsonObj = JSON.parse(Utils.getBufferText(buffer));
                 let place = this._createPlace(jsonObj, osmType, osmId);
                 callback(place);
             } catch(e) {
@@ -128,7 +122,7 @@ var Overpass = GObject.registerClass({
         let [lat, lon] = this._getCoordsFromElement(element);
         let photonProperties =
             this._getPhotonProperties(element.tags, osmType, osmId);
-        let place = PhotonParser.parsePlace(lat, lon, photonProperties);
+        let place = PhotonUtils.parsePlace(lat, lon, photonProperties);
 
         this._populatePlace(place, overpassData);
         place.prefilled = true;
@@ -221,32 +215,40 @@ var Overpass = GObject.registerClass({
     }
 
     _getQueryUrl(osmType, osmId) {
-        return Format.vprintf('%s?data=%s', [BASE_URL,
-                                             this._generateOverpassQuery(osmType,
-                                                                          osmId)]);
+        return `${BASE_URL}?data=${this._generateOverpassQuery(osmType, osmId)}`;
     }
 
     _generateOverpassQuery(osmType, osmId) {
-        return Format.vprintf('%s%s%s;%s;%s;',
-                              [ this._getKeyValue('timeout', this.timeout),
-                                this._getKeyValue('out', this.outputFormat),
-                                this._getKeyValue('maxsize', this.maxsize),
-                                this._getData(osmType, osmId),
-                                this._getOutput() ]);
+        let timeout = this._getKeyValue('timeout', this.timeout);
+        let out = this._getKeyValue('out', this.outputFormat);
+        let maxSize = this._getKeyValue('maxsize', this.maxsize);
+        let data = this._getData(osmType, osmId);
+        let output = this._getOutput();
+
+        return `${timeout}${out}${maxSize};${data};${output};`;
     }
 
     _getKeyValue(key, value) {
-        return Format.vprintf('[%s:%s]', [ key,
-                                           value ]);
+        return `[${key}:${value}]`;
     }
 
     _getData(osmType, osmId) {
-        return Format.vprintf('%s(%s)', [osmType, osmId]);
+        return `${osmType}(${osmId})`;
     }
 
     _getOutput() {
-        return Format.vprintf('out center %s %s %s', [ this.outputInfo,
-                                                       this.outputSortOrder,
-                                                       this.outputCount ]);
+        return `out center ${this.outputInfo} ${this.outputSortOrder} ${this.outputCount}`;
     }
-});
+}
+
+GObject.registerClass({
+    Properties: {
+        'place': GObject.ParamSpec.object('place',
+                                          'Place',
+                                          'Place with added information',
+                                          GObject.ParamFlags.READABLE |
+                                          GObject.ParamFlags.WRITABLE,
+                                          Geocode.Place)
+    }},
+    Overpass
+);
