@@ -19,23 +19,17 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-pkg.require({ 'Gdk': '3.0',
-              'Gtk': '3.0',
-              'Soup': '2.4' });
+import 'gi://Gdk?version=4.0';
+import 'gi://Gtk?version=4.0';
+import 'gi://Soup?version=3.0';
 
 const JsUnit = imports.jsUnit;
 
-const URIS = imports.uris;
+import * as URIS from './uris.js';
 
 const OSM_COORD_URL1 =
     'https://www.openstreetmap.org/?lat=39.9882&lon=-78.2409&zoom=14&layers=B000FTF';
 
-function main() {
-    parseAsObjectURLTest();
-    parseAsCoordinateURLTest();
-    parseMapsURITest();
-}
-
 function parseAsObjectURLTest() {
     _assertArrayEquals([], URIS.parseAsObjectURL('https://www.example.com'));
     _assertArrayEquals([], URIS.parseAsObjectURL('https://www.openstreet.org/'));
@@ -81,3 +75,7 @@ function _assertArrayEquals(arr1, arr2) {
     }
 }
 
+parseAsObjectURLTest();
+parseAsCoordinateURLTest();
+parseMapsURITest();
+
